@@ -240,3 +240,63 @@ class AreCAVolumesConsistent(ExperimentTest):
                                         % ",".join(res)])
         else:
             return Results(True, data=[])
+
+
+class HaveRawImagesValidIntensityRange(ExperimentTest):
+    """ASHS pipeline casts data from both input images -`MPRAGE` and `TSE`- to
+    'short' (16 bit) datatype. For input images with large intensity value ranges
+    (after scaling linear transformations are applied) that might lead to
+    erroneous or incomplete results. This test checks that the range of intensities
+    of ASHS input images (i.e. files `mprage_raw.nii` and `tse_raw.nii`) do not
+    exceed the maximum number of signed values represented with 16 bit (`2^15`).
+    Passes if ASHS raw input images have a range of intensity values smaller
+    than 32768. Fails otherwise."""
+
+    passing = 'BBRCDEV_E02803',
+    failing = 'BBRCDEV_E02802',
+
+    def run(self, experiment_id):
+        import os
+        import tempfile
+        import nibabel as nib
+        from nibabel.volumeutils import finite_range
+
+        res = True
+        data = []
+        r = self.xnat_instance.select.experiment(experiment_id).resource('ASHS')
+        if not r.exists():
+            return Results(False,
+                           data=['No ASHS resource found.'])
+
+        fh, fp = tempfile.mkstemp(suffix='.nii.gz')
+        os.close(fh)
+
+        for fname in ['mprage_raw.nii.gz', 'tse_raw.nii.gz']:
+            f = r.file(fname)
+            if not f.exists():
+                return Results(False,
+                               data=['ASHS file `{}` not found.'.format(fname)])
+            f.get(fp)
+            img = nib.load(fp).dataobj
+            min_val, max_val = finite_range(img)
+            range_val = len(range(min_val, max_val))
+            data.append([fname, str(range_val), str(min_val), str(max_val)])
+
+            if range_val >= 2**15:
+                res = False
+
+        return Results(res, data=data)
+
+    def report(self):
+        report = []
+
+        if len(self.results.data) > 1:
+            data = []
+            for fname, range_val, min_val, max_val in self.results.data:
+                data.append('`{}`: {} ({} - {})'.format(fname, range_val,
+                                                        min_val, max_val))
+            report.append('; '.join(data))
+        else:
+            report.append(self.results.data[0])
+
+        return report
