@@ -3,11 +3,11 @@ from ..test import ExperimentTest, Results
 
 class HasCorrectNumberOfItems(ExperimentTest):
     """Passes if a TOPUP_DTIFIT resource is found and such resource contains the
-    correct number of items (i.e. 50)."""
+    correct number of items (i.e. 48)."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
-    CORRECT_NUMBER = 50
+    CORRECT_NUMBER = 48
 
     def run(self, experiment_id):
         resource_name = 'TOPUP_DTIFIT'
@@ -30,14 +30,14 @@ class HasCorrectItems(ExperimentTest):
     the expected items according to the pipeline
     [specifications](https://gitlab.com/bbrc/xnat/xnat-pipelines/-/tree/master/dtifit#outputs)."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
         resource_name = 'TOPUP_DTIFIT'
         expected_items = ['acqparams.txt',
-                          'AP_b0.nii.gz',
                           'AP_PA_b0.nii.gz',
+                          'PA_b0_0.nii.gz',
                           '*_dn.nii.gz',
                           '*_dn_ec.eddy_command_txt',
                           '*_dn_ec.eddy_movement_rms',
@@ -64,8 +64,6 @@ class HasCorrectItems(ExperimentTest):
                           '*_dn_ec_fit_V3.nii.gz',
                           '*_dn_ec.nii.gz',
                           'index.txt',
-                          'PA_b0_0.nii.gz',
-                          'PA_b0_1.nii.gz',
                           'topup_fieldcoef.nii.gz',
                           'topup.log',
                           'topup_movpar.txt',
@@ -101,7 +99,7 @@ class HasCorrectMRtrix3Version(ExperimentTest):
     """This test checks the version of MRtrix3 used. Passes if TOPUP_DTIFIT
     outputs were created using the expected version (`3.0.2`)."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -133,7 +131,7 @@ class HasCorrectFSLVersion(ExperimentTest):
     """This test checks the version of FSL used. Passes if TOPUP_DTIFIT
     outputs were created using the expected version (`6.0.4:ddd0a010`)."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -163,7 +161,7 @@ class DTIFITSnapshotFA(ExperimentTest):
     generated by TOPUP_DTIFIT. Passes if the snapshot is created successfully.
     Fails otherwise. Does not tell anything on the segmentation quality."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E00272',
 
     def run(self, experiment_id):
@@ -214,7 +212,7 @@ class DTIFITSnapshotRGB(ExperimentTest):
     generated by TOPUP_DTIFIT. Passes if the snapshot is created successfully.
     Fails otherwise. Does not tell anything on the segmentation quality."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E00272',
 
     def run(self, experiment_id):
@@ -307,7 +305,7 @@ class DTIFITSnapshotTOPUP(ExperimentTest):
     original image (green colormap). Passes if the snapshot is created successfully.
     Fails otherwise. Does not tell anything on the segmentation quality."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -359,7 +357,7 @@ class HasFewNegativeVoxelsInMD(ExperimentTest):
     the Mean Diffusivity (MD) map has. Fails if the number of negative voxels
     found is higher than 2000. Passes otherwise."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -408,7 +406,7 @@ class HasAcceptableAverageSNR(ExperimentTest):
     the brain mask as a summary measure of overall data quality. Test passes if
     SNR > 20. Fails otherwise."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
     resource_name = 'TOPUP_DTIFIT'
     eddyqc_file = 'eddyqc/qc.json'
@@ -442,7 +440,7 @@ class HasAcceptableAverageCNR(HasAcceptableAverageSNR):
     contrast (i.e. higher CNR improves the estimation of complex fibre 
     configurations). Test passes if CNR > 2.5. Fails otherwise."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
@@ -464,7 +462,7 @@ class HasAcceptableOutliersPercentage(HasAcceptableAverageSNR):
     Test passes if the percentage of outliers found is lower than 1%. 
     Fails otherwise."""
 
-    passing = 'BBRCDEV_E02443',
+    passing = 'BBRCDEV_E02949',
     failing = 'BBRCDEV_E02824',
 
     def run(self, experiment_id):
