@@ -845,19 +845,17 @@ class HasCorrectSequenceAttributes(ExperimentTest):
                         else:
                             result = bool(value == dicom_attributes[tag])
                     elif isinstance(value, int):
+                        result = bool(int(dicom_attributes[tag]) == value)
+                    elif isinstance(value, float):
                         # exception: PixelBandwith diverges greatly at T1W,RS,
                         # ... Tolerance factor of +/- 1%
                         if tag == 'PixelBandwidth':
-                            import math
-                            tolerance = int(math.ceil(0.01 * value))
-                            result = bool(np.isclose(int(dicom_attributes[tag]),
+                            tolerance = 0.01 * value
+                            result = bool(np.isclose(float(dicom_attributes[tag]),
                                                      value, atol=tolerance))
-                        else:
-                            result = bool(int(dicom_attributes[tag]) == value)
-                    elif isinstance(value, float):
                         # exception: RepetitionTime diverges frequently.
                         # Tolerance factor of +/- 1 (absolute)
-                        if tag == 'RepetitionTime':
+                        elif tag == 'RepetitionTime':
                             result = bool(np.isclose(float(dicom_attributes[tag]),
                                                      value, atol=1))
                         # exception: AcquisitionDuration diverges (particularly
@@ -880,8 +878,8 @@ class HasCorrectSequenceAttributes(ExperimentTest):
                         elif tag == 'PixelSpacing':
                             result = all(np.isclose(
                                 np.asarray(
-                                    dicom_attributes[tag].split('\\')).astype(np.float),
-                                np.asarray(value).astype(np.float),
+                                    dicom_attributes[tag].split('\\')).astype(float),
+                                np.asarray(value).astype(float),
                                 atol=0.001))
                         # exception: SoftwareVersions can either be 5.1.9 or 5.4.0
                         elif tag == 'SoftwareVersion(s)':
@@ -1760,4 +1758,26 @@ class IsFMRIPrepRunnable(IsFreeSurferRunnable):
 
     passing = 'BBRCDEV_E02823',
     failing = 'BBRCDEV_E00013',
-    tests = [HasUsableT1, HasUsableRS, HasUsableSEap, HasUsableSEpa]
\ No newline at end of file
+    tests = [HasUsableT1, HasUsableRS, HasUsableSEap, HasUsableSEpa]
+
+
+class HasUsableSWI(HasUsableDWI):
+    passing = 'BBRCDEV_E00276',
+    failing = 'BBRCDEV_E00013',
+    scan_type = 'SWI'
+    required_tests = [IsClassicDICOM, HasUncompressedPixelData]
+    __doc__ = HasUsableDWI.__doc__.replace('Diffusion-weighted',
+                                           'Susceptibility weighted')
+    __doc__ = __doc__.replace('DWI', 'SWI')
+
+
+class IsQSMxTRunnable(IsFreeSurferRunnable):
+    """This test checks that a given MRSession fulfills the requirements to run
+    `QSMxT`, an automatic pipeline for reconstructing and processing quantitative
+    susceptibility mapping (QSM) images. `QSMxT` requires a T1w image and a SWI
+    image to run. This test passes if the right scan images can be found,
+    fails otherwise."""
+
+    passing = 'BBRCDEV_E00276',
+    failing = 'BBRCDEV_E00013',
+    tests = [HasUsableT1, HasUsableSWI]
