@@ -19,8 +19,9 @@ class IsScannerVersionCorrect(pet.IsScannerVersionCorrect):
 class HasUsableT1(pet.HasUsableT1):
     passing = 'BBRCDEV_E02957',
     failing = 'BBRCDEV_E02948',
-    included_projects = ['ALFA_PLUS', 'ALFA_PLUS2', 'ALFA_OPCIONAL',
-                         'ALFA_PLUS_V2', 'ALFA_PLUS2_V2', 'EPAD', 'testenv']
+    included_projects = ['testenv', 'ALFA_PLUS', 'ALFA_PLUS2', 'ALFA_OPCIONAL',
+                         'ALFA_PLUS_V2', 'ALFA_PLUS2_V2', 'EPAD', 'ALFA_PLUS_VX']
+    __doc__ = pet.HasUsableT1.__doc__
 
 
 class IsInjectionTimeConsistent(pet.IsInjectionTimeConsistent):
