@@ -155,7 +155,9 @@ class ArchivingValidator(Validator):
                  data.HasUsableRS,
                  data.HasUsableSEap,
                  data.HasUsableSEpa,
-                 data.IsFMRIPrepRunnable]
+                 data.IsFMRIPrepRunnable,
+                 data.HasUsableSWI,
+                 data.IsQSMxTRunnable]
         super(type(self), self).__init__(tests, lut, xnat_instance)
 
 
@@ -280,7 +282,8 @@ class ASHSValidator(Validator):
                  ashs.AreCAVolumesConsistent,
                  ashs.HasNormalSubfieldVolumes,
                  ashs.HasAllSubfields,
-                 ashs.ASHSSnapshot]
+                 ashs.ASHSSnapshot,
+                 ashs.HaveRawImagesValidIntensityRange]
         super(type(self), self).__init__(tests, lut, xnat_instance)
 
 
@@ -440,4 +443,48 @@ class DickersonValidator(Validator):
         from bbrc.validation.processing import dickerson
         tests = [dickerson.HasCorrectItems,
                  dickerson.HasCorrectFreeSurferVersion]
-        super(type(self), self).__init__(tests, lut, xnat_instance)
\ No newline at end of file
+        super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class QSMxTValidator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import qsmxt
+        tests = [qsmxt.HasCorrectItems,
+                 qsmxt.HasCorrectQSMxTVersion,
+                 qsmxt.IsBasalGangliaMeanQSMConsistent,
+                 qsmxt.IsT1Session1,
+                 qsmxt.IsT1Session3,
+                 qsmxt.HasExpectedAsegStructures]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class DartelNorm2MNIValidator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import dartel
+        tests = [dartel.HasCorrectItems,
+                 dartel.HasCorrectSPMVersion,
+                 dartel.HasCorrectMatlabVersion,
+                 dartel.HasCorrectOSVersion]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class DartelNorm2MNIT1T2Validator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import dartel_t1t2
+        tests = [dartel_t1t2.HasCorrectItems,
+                 dartel_t1t2.HasCorrectSPMVersion,
+                 dartel_t1t2.HasCorrectMatlabVersion,
+                 dartel_t1t2.HasCorrectOSVersion]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class FMRIPrepValidator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import fmriprep
+        tests = [fmriprep.HasCorrectItems,
+                 fmriprep.HasCorrectFMRIPrepVersion,
+                 fmriprep.HasCorrectHeuDiConvVersion,
+                 fmriprep.HasValidDcm2niixVersion,
+                 fmriprep.IsICANumberOfSignalComponentsConsistent,
+                 fmriprep.HasFewMotionOutlierVolumes]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
